@@ -1115,13 +1115,13 @@ formed, \n\n" % (model, attr)
         state = 'old'
 
         # Manage null values
-        #for attr, value in data.items():
-            #try:
-            #    data[attr] = value.strip(' \t\n\r\r\n')
-            #except:
-            #    pass
-            #if data[attr] == "":
-            #    del data[attr]
+        for attr, value in data.items():
+            try:
+                data[attr] = value.strip(' \t\n\r\r\n')
+            except:
+                pass
+            if data[attr] not in (0, False) and not data[attr]:
+                del data[attr]
 
         search = self._search(model, data, search)
 
@@ -1396,14 +1396,16 @@ formed, \n\n" % (model, attr)
                 data[item] = content
 
             #Cleaning dict items with null value
-            if data[item] not in (0, '0') and not data[item]:
+            if not data[item]:
                 if required:
-                    raise exceptions.RequiredFieldError(model, item, data[item], line, logger=self._logger)
-                #ToRemove.append(item)
+                    raise exceptions.RequiredFieldError(model,
+                            item, data[item], line, logger=self._logger)
+                if data[item] not in (0, False):
+                    ToRemove.append(item)
 
         # Cleaning data from given attributes
-        #for item in ToRemove:
-        #    del data[item]
+        for item in ToRemove:
+            del data[item]
         
         # Adding this to indicate that this field has been loaded
         data['CREATED::search'] = search
