@@ -269,7 +269,7 @@ class Router(BaseField):
     :type callback: function
 
     """
-    def __init__(self, column=None, callback=None):
+    def __init__(self, column=None, callback=None, **kwargs):
         attributes = []
         # Getting the calling frame from stack
         frame = stack()[0][0]
